emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/trunk r104949: * textprop.c (text_property_


From: Stefan Monnier
Subject: [Emacs-diffs] /srv/bzr/emacs/trunk r104949: * textprop.c (text_property_stickiness): Obey Vtext_property_default_nonsticky.
Date: Mon, 04 Jul 2011 14:31:29 -0400
User-agent: Bazaar (2.3.1)

------------------------------------------------------------
revno: 104949
committer: Stefan Monnier <address@hidden>
branch nick: trunk
timestamp: Mon 2011-07-04 14:31:29 -0400
message:
  * textprop.c (text_property_stickiness): Obey 
Vtext_property_default_nonsticky.
  (syms_of_textprop): Add `display' to Vtext_property_default_nonsticky.
  * w32fns.c (syms_of_w32fns):
  * xfns.c (syms_of_xfns): Don't Add `display' since it's there by default.
modified:
  src/ChangeLog
  src/textprop.c
  src/w32fns.c
  src/xfns.c
=== modified file 'src/ChangeLog'
--- a/src/ChangeLog     2011-07-04 17:50:12 +0000
+++ b/src/ChangeLog     2011-07-04 18:31:29 +0000
@@ -1,3 +1,11 @@
+2011-07-04  Stefan Monnier  <address@hidden>
+
+       * textprop.c (text_property_stickiness):
+       Obey Vtext_property_default_nonsticky.
+       (syms_of_textprop): Add `display' to Vtext_property_default_nonsticky.
+       * w32fns.c (syms_of_w32fns):
+       * xfns.c (syms_of_xfns): Don't Add `display' since it's there by 
default.
+
 2011-07-04  Paul Eggert  <address@hidden>
 
        * fileio.c (barf_or_query_if_file_exists): Use S_ISDIR.

=== modified file 'src/textprop.c'
--- a/src/w32fns.c      2011-06-22 18:15:23 +0000
+++ b/src/w32fns.c      2011-07-04 18:31:29 +0000
@@ -6805,10 +6805,6 @@
   DEFSYM (Qfont_param, "font-parameter");
   /* This is the end of symbol initialization.  */
 
-  /* Text property `display' should be nonsticky by default.  */
-  Vtext_property_default_nonsticky
-    = Fcons (Fcons (Qdisplay, Qt), Vtext_property_default_nonsticky);
-
 
   Fput (Qundefined_color, Qerror_conditions,
        pure_cons (Qundefined_color, pure_cons (Qerror, Qnil)));

=== modified file 'src/xfns.c'
--- a/src/xfns.c        2011-06-24 21:25:22 +0000
+++ b/src/xfns.c        2011-07-04 18:31:29 +0000
@@ -5805,10 +5805,6 @@
   DEFSYM (Qfont_param, "font-parameter");
   /* This is the end of symbol initialization.  */
 
-  /* Text property `display' should be nonsticky by default.  */
-  Vtext_property_default_nonsticky
-    = Fcons (Fcons (Qdisplay, Qt), Vtext_property_default_nonsticky);
-
   Fput (Qundefined_color, Qerror_conditions,
        pure_cons (Qundefined_color, pure_cons (Qerror, Qnil)));
   Fput (Qundefined_color, Qerror_message,


reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- a/src/textprop.c    2011-06-24 21:25:22 +0000
+++ b/src/textprop.c    2011-07-04 18:31:29 +0000
@@ -1707,10 +1707,14 @@
 {
   Lisp_Object prev_pos, front_sticky;
   int is_rear_sticky = 1, is_front_sticky = 0; /* defaults */
+  Lisp_Object defalt = Fassq (prop, Vtext_property_default_nonsticky);
 
   if (NILP (buffer))
     XSETBUFFER (buffer, current_buffer);
 
+  if (CONSP (defalt) && !NILP (XCDR (defalt)))
+    is_rear_sticky = 0;
+
   if (XINT (pos) > BUF_BEGV (XBUFFER (buffer)))
     /* Consider previous character.  */
     {
@@ -2230,9 +2234,11 @@
 the character doesn't inherit PROPERTY if NONSTICKINESS is non-nil,
 inherits it if NONSTICKINESS is nil.  The `front-sticky' and
 `rear-nonsticky' properties of the character override NONSTICKINESS.  */);
-  /* Text property `syntax-table' should be nonsticky by default.  */
+  /* Text properties `syntax-table'and `display' should be nonsticky
+     by default.  */
   Vtext_property_default_nonsticky
-    = Fcons (Fcons (intern_c_string ("syntax-table"), Qt), Qnil);
+    = Fcons (Fcons (intern_c_string ("syntax-table"), Qt),
+            Fcons (Fcons (intern_c_string ("display"), Qt), Qnil));
 
   staticpro (&interval_insert_behind_hooks);
   staticpro (&interval_insert_in_front_hooks);

=== modified file 'src/w32fns.c'